@@ -6,7 +6,7 @@ use POE qw(Component::SmokeBox::Backend Component::SmokeBox::Job Component::Smok
 use Params::Check qw(check);
 use vars qw($VERSION);
 
-$VERSION = '0.43_01';
+$VERSION = '0.01';
 
 # Stolen from POE::Wheel. This is static data, shared by all
 my $current_id = 0;
@@ -16,7 +16,6 @@ sub spawn {
   my $package = shift;
   my %params = @_;
   $params{lc $_} = delete $params{$_} for keys %params;
-  $params{'delay'} = 0 unless exists $params{'delay'};
   my $options = delete $params{'options'};
   my $self = bless \%params, $package;
   $self->{session_id} = POE::Session->create(
@@ -26,7 +25,7 @@ sub spawn {
 		submit     => '_submit',
 		cancel     => '_cancel',
            },
-           $self => [qw(_start _process_queue _backend_done _process_queue_delayed)],
+           $self => [qw(_start _process_queue _backend_done)],
         ],
 	heap => $self,
 	( ref($options) eq 'HASH' ? ( options => $options ) : () ),
@@ -40,7 +39,7 @@ sub session_id {
 
 sub shutdown {
   my $self = shift;
-  $poe_kernel->call( $self->session_id() => 'shutdown' => @_ );
+  $poe_kernel->post( $self->session_id() => 'shutdown' => @_ );
 }
 
 sub _start {
@@ -68,41 +67,17 @@ sub _shutdown {
   # shutdown currently running backend
   $self->{_current}->{backend}->shutdown() if $self->{_current}->{backend};
   # remove queued jobs.
-#  $kernel->refcount_decrement( $_->{session}, __PACKAGE__ ) for @{ $self->{_queue} };
-  $kernel->refcount_decrement( $_, __PACKAGE__ ) for keys %{ $self->{_refcounts} };
+  $kernel->refcount_decrement( $_->{session}, __PACKAGE__ ) for @{ $self->{_queue} };
   delete $self->{_queue};
-
-  # remove delay for jobs if we set one
-  $kernel->alarm_remove( delete $self->{_delay} ) if exists $self->{_delay};
-
-  return;
-}
-
-sub _process_queue_delayed {
-  my ($kernel,$self) = @_[KERNEL,OBJECT];
-  delete $self->{_delay} if exists $self->{_delay};
-  $kernel->yield( '_process_queue', 'DELAYDONE' );
   return;
 }
 
 sub _process_queue {
-  my ($kernel,$self,$delaydone) = @_[KERNEL,OBJECT,ARG0];
-  return if $self->{_shutdown};
-  return if exists $self->{_delay};
-  return if exists $self->{paused} and $self->{paused} == 2;
+  my ($kernel,$self) = @_[KERNEL,OBJECT];
   my ($job, $smoker );
   if ( $self->{_current} ) {
      return if $self->{_current}->{backend};
      $job = $self->{_current};
-
-     # do we have a delay between smokers?
-     if ( $job->{job}->delay > 0 and ! defined $delaydone and scalar @{ $job->{smokers} } > 0 ) {
-	# fire off an alarm for the next iteration
-	#warn "Setting delay(" . $job->{job}->delay . ") for smoker" if $ENV{PERL5_SMOKEBOX_DEBUG};
-	$self->{_delay} = $kernel->delay_set( '_process_queue_delayed' => $job->{job}->delay );
-	return;
-     }
-
      $smoker = shift @{ $job->{smokers} };
      unless ( $smoker ) {
 	# Reached the end send an event back to the original requestor
@@ -110,21 +85,8 @@ sub _process_queue {
 	delete $job->{smokers};
 	my $session = delete $job->{session};
 	$kernel->post( $session, delete $job->{event}, $job );
-	$self->{_refcounts}->{ $session }--;
-	if ( $self->{_refcounts}->{ $session } <= 0 ) {
-	   $kernel->refcount_decrement( $session, __PACKAGE__ );
-	   delete $self->{_refcounts}->{ $session };
-	}
-
-	# did we enable delay between jobs?
-	# don't check the queue, we force a delay all the time so if we add a job, we're already delaying for it...
-	if ( $self->{delay} > 0 ) {
-	   # fire off an alarm for the next iteration
-	   #warn "Setting delay($self->{delay}) for job" if $ENV{PERL5_SMOKEBOX_DEBUG};
-	   $self->{_delay} = $kernel->delay_set( '_process_queue_delayed' => $self->{delay} );
-	} else {
-  	   $kernel->yield( '_process_queue' );
-	}
+	$kernel->refcount_decrement( $session, __PACKAGE__ );
+  	$kernel->yield( '_process_queue' );
 	return;
      }
   }
@@ -190,10 +152,7 @@ sub _submit {
   my $type = delete $checked->{type};
   my $id = $self->_add_job( $checked, $type );
   return unless $id;
-  unless ( defined $self->{_refcounts}->{ $checked->{session} } ) {
-    $kernel->refcount_increment( $checked->{session}, __PACKAGE__ );
-  }
-  $self->{_refcounts}->{ $checked->{session} }++;
+  $kernel->refcount_increment( $checked->{session}, __PACKAGE__ );
   $checked->{submitted} = time();
   #$checked->{job}->id( $id );
   return $id;
@@ -302,11 +261,6 @@ sub pause_queue {
   $self->{paused} = 1;
 }
 
-sub pause_queue_now {
-  my $self = CORE::shift;
-  $self->{paused} = 2;
-}
-
 sub resume_queue {
   my $self = CORE::shift;
   delete $self->{paused};
@@ -314,11 +268,7 @@ sub resume_queue {
 }
 
 sub queue_paused {
-  if ( exists $_[0]->{paused} ) {
-    return 1;
-  } else {
-    return 0;
-  }
+  return $_[0]->{paused};
 }
 
 sub current_job {
@@ -349,7 +299,7 @@ POE::Component::SmokeBox::JobQueue - An array based queue for SmokeBox
 
   use strict;
   use warnings;
-  use data::Dumper;
+  use Data::Dumper;
   use POE qw(Component::SmokeBox::JobQueue Component::SmokeBox::Job Component::SmokeBox::Smoker);
 
   my $perl = 'home/cpan/rel/perl-5.8.8/bin/perl';
@@ -409,7 +359,6 @@ Creates a new POE::Component::SmokeBox::JobQueue object. Takes a number of optio
 
   'alias', specify a POE::Kernel alias for the component;
   'options', a hashref of POE::Session options to pass to the poco's POE::Session;
-  'delay', the time in seconds to wait between job runs, default is 0;
 
 =back
 
@@ -475,10 +424,6 @@ Returns a hashref to the currently processing job, if there is one, undef otherw
 Pauses the jobqueue. Any currently processing jobs will be completed, but nothing else will be processed until the
 queue is resumed.
 
-=item C<pause_queue_now>
-
-Same as C<pause_queue> but also halts any currently processing job.
-
 =item C<resume_queue>
 
 Resumes the processing of a previously paused jobqueue.
@@ -514,7 +459,6 @@ Each result is a hashref:
   'idle_kill', only present if the job was killed because of excessive idle;
   'excess_kill', only present if the job was killed due to excessive runtime;
   'term_kill', only present if the job was killed due to a poco shutdown event;
-  'cb_kill', only present if the job was killed due to the callback returning false;
 
 =head1 AUTHOR
 
